Groups
------

.. automodule:: ls.joyous.models.groups

.. autofunction:: get_group_model_string
.. autofunction:: get_group_model

.. automodule:: ls.joyous.models

.. autoclass:: GroupPage
    :show-inheritance:

    .. attribute:: content

    An area of text for whatever you like


